@@ -7,7 +7,7 @@ __author__ = "Patrick Kunzmann", "Thomas Nevolianis"
 __all__ = ["GeneralSequence", "NucleotideSequence", "ProteinSequence"]
 
 from .sequence import Sequence
-from .alphabet import LetterAlphabet, AlphabetError
+from .alphabet import LetterAlphabet, AlphabetError, AlphabetMapper
 import numpy as np
 import copy
 
@@ -31,7 +31,12 @@ class GeneralSequence(Sequence):
     def __init__(self, alphabet, sequence=()):
         self._alphabet = alphabet
         super().__init__(sequence)
-    
+
+    def __repr__(self):
+        """Represent GeneralSequence as a string for debugging."""
+        return f"GeneralSequence(Alphabet({self._alphabet}), " \
+               f"[{', '.join([repr(symbol) for symbol in self.symbols])}])"
+
     def __copy_create__(self):
         return GeneralSequence(self._alphabet)
     
@@ -117,13 +122,12 @@ class NucleotideSequence(Sequence):
                          "D" : "H",
                          "B" : "V",
                          "N" : "N"}
-    _compl_dict = {}
-    for _key, _value in compl_symbol_dict.items():
-        _key_code = alphabet_amb.encode(_key)
-        _val_code = alphabet_amb.encode(_value)
-        _compl_dict[_key_code] = _val_code
-    # Vectorized function that returns a complement code
-    _complement_func = np.vectorize(_compl_dict.__getitem__)
+    # List comprehension does not work in this scope
+    _compl_symbols = []
+    for _symbol in alphabet_amb.get_symbols():
+        _compl_symbols.append(compl_symbol_dict[_symbol])
+    _compl_alphabet_unamb = LetterAlphabet(_compl_symbols)
+    _compl_mapper = AlphabetMapper(_compl_alphabet_unamb, alphabet_amb)
     
     def __init__(self, sequence=[], ambiguous=None):
         if isinstance(sequence, str):
@@ -145,7 +149,15 @@ class NucleotideSequence(Sequence):
             seq_code = self._alphabet.encode_multiple(sequence)
         super().__init__()
         self.code = seq_code
-        
+
+    def __repr__(self):
+        """Represent NucleotideSequence as a string for debugging."""
+        if self._alphabet == NucleotideSequence.alphabet_amb:
+            ambiguous = True
+        else:
+            ambiguous = False
+        return f'NucleotideSequence("{"".join(self.symbols)}", ambiguous={ambiguous})'
+
     def __copy_create__(self):
         if self._alphabet == NucleotideSequence.alphabet_amb:
             seq_copy = NucleotideSequence(ambiguous=True)
@@ -175,7 +187,12 @@ class NucleotideSequence(Sequence):
         AAGCGT
         
         """
-        compl_code = NucleotideSequence._complement_func(self.code)
+        # Interpreting the sequence code of this object in the
+        # complementary alphabet gives the complementary symbols
+        # In order to get the complementary symbols in the original
+        # alphabet, the sequence code is mapped from the complementary
+        # alphabet into the original alphabet
+        compl_code = NucleotideSequence._compl_mapper[self.code]
         return self.copy(compl_code)
     
     def translate(self, complete=False, codon_table=None, met_start=False):
@@ -302,10 +319,29 @@ class NucleotideSequence(Sequence):
     
     @staticmethod
     def unambiguous_alphabet():
+        """
+        Get the unambiguous nucleotide alphabet containing the symbols
+        ``A``,  ``C``,  ``G`` and  ``T``.
+
+        Returns
+        -------
+        alphabet : LetterAlphabet
+            The unambiguous nucleotide alphabet.
+        """
         return NucleotideSequence.alphabet_unamb
     
     @staticmethod
     def ambiguous_alphabet():
+        """
+        Get the ambiguous nucleotide alphabet containing the symbols
+        ``A``,  ``C``,  ``G`` and  ``T`` and symbols describing
+        ambiguous combinations of these.
+
+        Returns
+        -------
+        alphabet : LetterAlphabet
+            The ambiguous nucleotide alphabet.
+        """
         return NucleotideSequence.alphabet_amb
 
 
@@ -435,7 +471,11 @@ class ProteinSequence(Sequence):
         sequence = [dict_3to1[symbol.upper()] if len(symbol) == 3
                     else symbol.upper() for symbol in sequence]
         super().__init__(sequence)
-    
+
+    def __repr__(self):
+        """Represent ProteinSequence as a string for debugging."""
+        return f'ProteinSequence("{"".join(self.symbols)}")'
+
     def get_alphabet(self):
         return ProteinSequence.alphabet
     
